﻿using Infragistics.Web.UI.NavigationControls;
using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class _Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        DataSet set = new DataSet();
        //Add two tables
        set.Tables.Add(BuildTable("Menu2"));
        set.Tables.Add(BuildChildTable("Menu3"));

        //Create relations
        DataColumn parentColumn = set.Tables["Menu2"].Columns["Menu2_ItemID"];
        DataColumn childColumn = set.Tables["Menu3"].Columns["Menu3_parentID"];
        DataRelation relation = new DataRelation("RelationName", parentColumn, childColumn);
        set.Relations.Add(relation);

        DataTreeNodeBinding binding = new DataTreeNodeBinding();
        binding.ValueField = "Menu2_Nm";
        binding.TextField = "Menu2_Nm";
        binding.KeyField = "Menu2_ItemID";
        binding.DataMember = "Menu2"; // or binding.Depth = 0;
        this.WebDataTree2.DataBindings.Add(binding);

        binding = new DataTreeNodeBinding();
        binding.ValueField = "Menu3_Nm";
        binding.TextField = "Menu3_Nm";
        binding.KeyField = "Menu3_ItemID";
        binding.DataMember = "Menu3"; // or binding.Depth = 1;
        this.WebDataTree2.DataBindings.Add(binding);


        this.WebDataTree2.DataSource = set;
        this.WebDataTree2.DataBind();

        // Bind to IEnumerable, declarative bindings
        this.WebDataTree1.DataSource = GetBooks();
        this.WebDataTree1.DataBind();

        // extra unbound node adding through API
        DataTreeNode node = new DataTreeNode { Text = "Extra node", Value = "test" };
        node.Nodes.Add(new DataTreeNode { Text = "Extra node child", Value = "test2" });
        WebDataTree1.Nodes.Add(node);
    }

    #region Data Tables
    private DataTable BuildTable(string name)
    {

        DataTable table = new DataTable(name);
        DataColumn column;
        DataRow row;

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "Menu2_ItemID";
        column.ReadOnly = true;
        table.Columns.Add(column);

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.String");
        column.ColumnName = "Menu2_Nm";
        column.AutoIncrement = false;
        column.Caption = "Menu2_Nm";
        column.ReadOnly = false;
        column.Unique = false;
        table.Columns.Add(column);


        DataColumn[] PrimaryKeyColumns = new DataColumn[1];
        PrimaryKeyColumns[0] = table.Columns["id"];
        table.PrimaryKey = PrimaryKeyColumns;

        for (int i = 0; i <= 20; i++)
        {
            row = table.NewRow();
            row["Menu2_ItemID"] = i;
            row["Menu2_Nm"] = "Item " + i;
            table.Rows.Add(row);
        }
        return table;

    }

    private DataTable BuildChildTable(string name)
    {
        DataTable table = new DataTable(name);
        DataColumn column;
        DataRow row;

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "Menu3_ItemID";
        column.ReadOnly = true;
        table.Columns.Add(column);

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.String");
        column.ColumnName = "Menu3_Nm";
        column.AutoIncrement = false;
        column.Caption = "Menu3_Nm";
        column.ReadOnly = false;
        column.Unique = false;
        table.Columns.Add(column);


        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "Menu3_parentID";
        column.AutoIncrement = false;
        column.Caption = "Menu3_parentID";
        column.ReadOnly = false;
        column.Unique = false;
        table.Columns.Add(column);

        DataColumn[] PrimaryKeyColumns = new DataColumn[1];
        PrimaryKeyColumns[0] = table.Columns["id"];
        table.PrimaryKey = PrimaryKeyColumns;

        for (int i = 0; i <= 100; i++)
        {
            row = table.NewRow();
            row["Menu3_ItemID"] = i;
            row["Menu3_Nm"] = "Item " + i;


            if ((i < 10) && (i >= 0))
            {

                row["Menu3_parentID"] = 0;
            }
            else if ((i < 20) && (i >= 10))
            {
                row["Menu3_parentID"] = 1;
            }
            else if ((i < 30) && (i >= 20))
            {
                row["Menu3_parentID"] = 2;
            }
            else if ((i < 40) && (i >= 30))
            {
                row["Menu3_parentID"] = 3;
            }
            else if ((i < 50) && (i >= 40))
            {
            }
            table.Rows.Add(row);
        }
        return table;

    }
    #endregion

    #region List Data
    public IList<Book> GetBooks()
    {
        List<Book> books = new List<Book>();

        books.Add(new Book { ID = 0, Title = "The Elegant Universe", Author = "Brian Greene", UnitPrice = "15.95", Url = "http://www.amazon.com/Elegant-Universe-Superstrings-Dimensions-Ultimate/dp/0393046885", ReleaseDate = "02/01/1999" });

        books[0].Chapters.Add(new Chapter { Title = "Tied Up with String" });
        books[0].Chapters.Add(new Chapter { Title = "Space, Time, and the Eye of the Beholder" });
        books[0].Chapters.Add(new Chapter { Title = "Of Warps and Ripples" });
        books[0].Chapters.Add(new Chapter { Title = "Microscopic Weirdness" });
        books[0].Chapters.Add(new Chapter { Title = "Beyond Strings: In Search of M-Theory" });
        books[0].Chapters.Add(new Chapter { Title = "Black Holes: A String/M-Theory Perspective" });
        books[0].Chapters.Add(new Chapter { Title = "Reflections on Cosmology" });
        books[0].Chapters.Add(new Chapter { Title = "Prospects" });

        books.Add(new Book { ID = 1, Title = "The Selfish Gene (30th Anniversary Edition)", Author = "Richard Dawkins", UnitPrice = "15.95", Url = "http://www.amazon.com/Selfish-Gene-Anniversary-Introduction/dp/0199291152", ReleaseDate = "05/25/2006" });

        books[1].Chapters.Add(new Chapter { Title = "Why are people?" });
        books[1].Chapters.Add(new Chapter { Title = "The replicators" });
        books[1].Chapters.Add(new Chapter { Title = "Immortal coils" });
        books[1].Chapters.Add(new Chapter { Title = "The gene machine" });
        books[1].Chapters.Add(new Chapter { Title = "Memes: the new replicators" });
        books[1].Chapters.Add(new Chapter { Title = "Nice guys finish first" });
        books[1].Chapters.Add(new Chapter { Title = "The long reach of the gene" });


        books.Add(new Book { ID = 2, Title = "The Ideological Origins of the American Revolution (Enlarged Edition)", Author = "Bernard Bailyn", UnitPrice = "24.00", Url = "http://www.amazon.com/Ideological-Origins-American-Revolution/dp/0674443020", ReleaseDate = "03/01/1992" });

        books[2].Chapters.Add(new Chapter { Title = "The Literature of Revolution" });
        books[2].Chapters.Add(new Chapter { Title = "Sources and Traditions" });
        books[2].Chapters.Add(new Chapter { Title = "Power and Liberty: A Theory of Politics" });
        books[2].Chapters.Add(new Chapter { Title = "The Logic of Rebellion" });
        books[2].Chapters.Add(new Chapter { Title = "Transformation" });
        books[2].Chapters.Add(new Chapter { Title = "The Contagions of Liberty" });
        books[2].Chapters.Add(new Chapter { Title = "Fulfillment: A Commentary on the Constitution" });

        books.Add(new Book { ID = 3, Title = "Gödel, Escher, Bach: an Eternal Golden Braid", Author = "Douglas R. Hofstadter", UnitPrice = "20.00", Url = "http://www.amazon.com/Godel-Escher-Bach-Douglas-Hofstadter/dp/B001IAM392", ReleaseDate = "01/01/1999" });

        books[3].Chapters.Add(new Chapter { Title = "The MU-puzzle." });
        books[3].Chapters.Add(new Chapter { Title = "Meaning and Form in Mathematics." });
        books[3].Chapters.Add(new Chapter { Title = "Figure and Ground." });
        books[3].Chapters.Add(new Chapter { Title = "Consistency, Completeness, and Geometry." });
        books[3].Chapters.Add(new Chapter { Title = "Recursive Structures and Processes." });
        books[3].Chapters.Add(new Chapter { Title = "The Location of Meaning." });
        books[3].Chapters.Add(new Chapter { Title = "The Propositional Calculus." });
        books[3].Chapters.Add(new Chapter { Title = "Typographical Number Theory." });

        return books;
    }
    #endregion
}

#region Book

public class Book
{
    public int ID { get; set; }
    public string Title { get; set; }
    public string Author { get; set; }
    public string UnitPrice { get; set; }
    public string Url { get; set; }
    public string ImageUrl { get; set; }
    public string ReleaseDate { get; set; }
    public List<Chapter> Chapters { get; set; }
    public List<Chapter> OtherChapters { get; set; }

    public Book()
    {
        Chapters = new List<Chapter>();
        OtherChapters = new List<Chapter>();
        ImageUrl = "http://www.infragistics.com/samplesbrowser/samplescommon/aspnet/Common/OfficeBasicsIcons/Book.gif";
    }
}


public class Chapter
{
    public int ID { get; set; }
    public string Title { get; set; }
    public string ImageUrl { get; set; }

    public Chapter()
    {
        ImageUrl = "http://www.infragistics.com/samplesbrowser/samplescommon/aspnet/Common/SilDVSampleIcons/Generic.gif";
    }
}

#endregion